@@ -278,6 +278,6 @@ class CascadeCMSRestDriver:
         elif originalSiteName:
             key, val = 'originalSiteName', originalSiteName
         return self.session.post(url, data=json.dumps({
-            'key': val,
+            key: val,
             'newSitenName': newSiteName
         })).json()
